"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var bn_js_1 = tslib_1.__importDefault(require("bn.js"));
exports.isAddress = function (address) {
    return exports.isByteString(address, 40);
};
exports.isPrivateKey = function (privateKey) {
    return exports.isByteString(privateKey, 64);
};
exports.isPubKey = function (pubKey) {
    return exports.isByteString(pubKey, 66);
};
exports.isSignature = function (sig) {
    return exports.isByteString(sig, 128);
};
exports.isByteString = function (str, len) {
    return !!str.replace('0x', '').match("^[0-9a-fA-F]{" + len + "}$");
};
exports.isNumber = function (x) {
    return typeof x === 'number';
};
exports.isBN = function (x) {
    return bn_js_1.default.isBN(x);
};
exports.isString = function (x) {
    return typeof x === 'string';
};
exports.isPlainObject = function (x) {
    if (typeof x === 'object' && x !== null) {
        var proto = Object.getPrototypeOf(x);
        return proto === Object.prototype || proto === null;
    }
    return false;
};
var PRAGMA_REQUIRED = '@@ZJS_REQUIRED@@';
exports.required = function (fn) {
    if (typeof fn === 'function') {
        return Object.defineProperty(fn, 'required', {
            value: PRAGMA_REQUIRED,
        });
    }
    throw new Error('fn is not a function');
};
exports.matchesObject = function (x, test) {
    if (exports.isPlainObject(x)) {
        for (var key in test) {
            for (var i = 0; i < test[key].length; i++) {
                var value = x[key];
                if (typeof value === 'undefined') {
                    if (test[key][i].required) {
                        throw new Error('Key not found: ' + key);
                    }
                    continue;
                }
                if (typeof test[key][i] !== 'function')
                    throw new Error('Validator is not a function');
                if (!test[key][i](x[key]))
                    throw new Error('Validation failed for ' + key);
            }
        }
    }
    return true;
};
//# sourceMappingURL=validation.js.map